import { EventEmitter2 } from 'eventemitter2';
import { ChatState, MUCAffiliation, MessageType } from 'stanza/Constants';
import { MAMFin, Paging } from 'stanza/protocol';
import { WacRequest } from './WacRequest';
import { XmppClient } from './XmppClient';
interface Message {
    id: string;
    from: string;
    to: string;
    timestamp: number;
    body: string;
    links: string;
    displayed?: string;
    received?: string;
}
interface MessageQueryResult {
    results: Message[];
    complete: boolean;
    paging: Paging;
}
interface PushNotificationConfig {
    jid: string;
    type: 'apn' | 'fcm' | 'web-push';
    token: string;
    node: string;
}
export declare class ChatService {
    private wacRequest;
    private sessionToken;
    private pushUri;
    xmppClient: XmppClient;
    emitter: EventEmitter2;
    constructor(wacRequest: WacRequest, sessionToken: string, xmppClient: XmppClient, pushUri: string);
    start(): Promise<void>;
    stop(): Promise<void>;
    bindEventListeners(): void;
    unbindEventListeners(): void;
    onIndividualChatChanges(event: any): void;
    onMarkerReceived(event: any): void;
    onMarkerDisplayed(event: any): void;
    onChat(event: any): void;
    onMucInvite(event: any): void;
    onMucLeave(event: any): void;
    onMucTopic(event: any): void;
    onMucOther(event: any): Promise<void>;
    onChatState(event: any): void;
    onPresence(event: any): void;
    onMessageSent(event: any): void;
    onMessage(event: any): void;
    onMessageError(event: any): void;
    getIndividualChats(): Promise<string[]>;
    addIndividualChat(jid: string): Promise<void>;
    deleteIndividualChat(jid: string): Promise<void>;
    getRoomInfo(jid: string): Promise<{
        name: string;
        subject: string;
    }>;
    getBookmarks(): Promise<string[]>;
    addBookmark(jid: string): Promise<void>;
    removeBookmark(jid: string): Promise<void>;
    createRoom(creator: string, name?: string, subject?: string): Promise<string>;
    setRoomName(jid: string, name: string): Promise<void>;
    setRoomSubject(jid: string, subject: string): void;
    getRoomMembers(jid: string): Promise<Array<{
        affiliation: MUCAffiliation;
        jid: string;
    }>>;
    joinRoom(jid: string, nick: string): Promise<void>;
    invite(room: string, tos: string[] | string): Promise<void>;
    expel(room: string, to: string): Promise<void>;
    setParticipantRole(room: string, to: string, role: MUCAffiliation): Promise<void>;
    leave(room: string): Promise<void>;
    destroy(jid: string, reason?: string): Promise<void>;
    setState(to: string, type: MessageType, chatState: ChatState): Promise<void>;
    fetchMessages(jid: string, type: MessageType, lastForwardedMessage: string, max?: number): Promise<MessageQueryResult>;
    sync(jid: string, type: MessageType, start: number): Promise<Message[]>;
    syncMucInvitations(to: string): Promise<MAMFin | undefined>;
    sendMessage(to: string, type: MessageType, body: string): Promise<void>;
    sendFile(to: string, type: MessageType, url: string, description: string): Promise<void>;
    markReceived(to: string, id: string, type: MessageType): void;
    markDisplayed(to: string, id: string, type: MessageType): void;
    enableNotifications(config: PushNotificationConfig): Promise<void>;
    disableNotifications(config: PushNotificationConfig): Promise<void>;
    private processMamMessages;
    getSupportChats(): Promise<unknown>;
    leaveSupportChat(id: string): Promise<unknown>;
    createSupportChat(id: string, context: string): Promise<unknown>;
    transferSupportChat(id: string, destination: string): Promise<unknown>;
}
export {};
