import { EventEmitter2 } from 'eventemitter2';
import { MAMQueryOptions } from 'stanza';
import { MUCAffiliation, MessageType } from 'stanza/Constants';
import { DataForm, DataFormField, DiscoInfoResult, IQ, MAMFin, MUCBookmark, MUCConfigure, MUCDestroy, MUCInvite, MUCUserList, Message, Presence } from 'stanza/protocol';
interface RequestFileUploadSlotResponse {
    downloadUrl: string;
    uploadUrl: string;
    uploadHeaders: Array<{
        name: string;
        value: string;
    }>;
}
export declare class XmppClient {
    emitter: EventEmitter2;
    private lock;
    private throttleLock;
    private mucJoinPromise;
    private messagePromise;
    private client;
    private started;
    private reconnectingInterval;
    constructor(chatUri: string, token: string, jid: string);
    start(): Promise<void>;
    stop(): Promise<void>;
    private connectClient;
    disconnectClient(): Promise<void>;
    onDisconnected(): void;
    bindEventListeners(): void;
    unbindEventListeners(): void;
    sendMessage(message: Message): Promise<void>;
    markReceived(to: string, id: string, type: MessageType): void;
    markDisplayed(to: string, id: string, type: MessageType): void;
    private sendMark;
    searchHistory(query: MAMQueryOptions): Promise<MAMFin>;
    getBookmarks(): Promise<MUCBookmark[]>;
    addBookmark(bookmark: MUCBookmark): Promise<void>;
    removeBookmark(jid: string): Promise<void>;
    getDiscoInfo(jid: string): Promise<DiscoInfoResult>;
    getRoomConfig(jid: string): Promise<DataForm>;
    configureRoom(room: string, form: Partial<DataForm>): Promise<IQ & {
        muc: MUCConfigure;
    }>;
    destroyRoom(room: string, options: MUCDestroy): Promise<IQ & {
        muc: MUCConfigure;
    }>;
    getRoomMembers(jid: string, affiliation: MUCAffiliation): Promise<IQ & {
        muc: MUCUserList;
    }>;
    joinRoom(jid: string, nick: string, options?: Presence): Promise<void>;
    invite(room: string, options: MUCInvite | MUCInvite[]): void;
    setRoomAffiliation(room: string, jid: string, affiliation: MUCAffiliation, reason?: string): Promise<IQ & {
        muc: MUCUserList;
    }>;
    setSubject(room: string, subject: string): void;
    deleteAccount(jid: string): Promise<void>;
    enableNotifications(jid: string, node: string, fieldList: DataFormField[]): Promise<IQ>;
    disableNotifications(jid: string, node: string): Promise<IQ>;
    requestFileUploadSlot(jid: string, name: string, size: number, mediaType?: string): Promise<RequestFileUploadSlotResponse>;
    private onEvent;
    private onStanzaAcked;
    private onMucError;
    private onMucJoin;
}
export {};
